const CAMERA_ENV = {

    video : null,
    canvas : null,
    takePhotoBtn : null,
    photoImg : null,
    width : 640 ,
    height : 480 ,

};

const CAMERA = {

    init: function () {

        // Prefer camera resolution nearest to 1280x720.
        // const constraints = {audio: false, video: {width: 1280, height: 720}};

        // Older browsers might not implement mediaDevices at all, so we set an empty object first
        if (navigator.mediaDevices === undefined) {
            navigator.mediaDevices = {};
        }

        // Some browsers partially implement mediaDevices. We can't just assign an object
        // with getUserMedia as it would overwrite existing properties.
        // Here, we will just add the getUserMedia property if it's missing.
        if (navigator.mediaDevices.getUserMedia === undefined) {
            navigator.mediaDevices.getUserMedia = function (constraints) {

                // First get ahold of the legacy getUserMedia, if present
                let getUserMedia = navigator.webkitGetUserMedia || navigator.mozGetUserMedia;

                // Some browsers just don't implement it - return a rejected promise with an error
                // to keep a consistent interface
                if (!getUserMedia) {
                    return Promise.reject(new Error('getUserMedia is not implemented in this browser'));
                }

                // Otherwise, wrap the call to the old navigator.getUserMedia with a Promise
                return new Promise(function (resolve, reject) {
                    getUserMedia.call(navigator, constraints, resolve, reject);
                });
            }
        }
    },

    setVideoObj: function () {
        // audio : false, video: true
        navigator.mediaDevices.getUserMedia({audio: false, video: true})
            .then(function (stream) {
                // let video = document.querySelector("video");
                let video = CAMERA_ENV.video;
                // video.width = CAMERA_ENV.width;
                // video.height = CAMERA_ENV.height;
                // Older browsers may not have srcObject
                if ("srcObject" in video) {
                    video.srcObject = stream;
                } else {
                    // Avoid using this in new browsers, as it is going away.
                    video.src = window.URL.createObjectURL(stream);
                }
                video.onloadedmetadata = function (e) {
                    video.play();
                };
            })
            .catch(function (err) {
                console.log(err.name + ": " + err.message);
            });

        CAMERA.clearPhoto();

        CAMERA_ENV.takePhotoBtn.addEventListener('click', function(ev){
            CAMERA.takePhoto();
            ev.preventDefault();
        }, false);
    },

    takePhoto : function (){
        let context = CAMERA_ENV.canvas.getContext('2d');
        if (CAMERA_ENV.width && CAMERA_ENV.height) {
            CAMERA_ENV.canvas.width = CAMERA_ENV.width;
            CAMERA_ENV.canvas.height = CAMERA_ENV.height;
            context.drawImage(CAMERA_ENV.video, 0, 0, CAMERA_ENV.width, CAMERA_ENV.height);

            let data = CAMERA_ENV.canvas.toDataURL('image/png');
            CAMERA_ENV.photoImg.setAttribute('src', data);
        } else {
            CAMERA.clearPhoto();
        }
    },

    clearPhoto : function (){
        let context = CAMERA_ENV.canvas.getContext('2d');
        context.fillStyle = "#AAA";
        context.fillRect(0, 0, CAMERA_ENV.canvas.width, CAMERA_ENV.canvas.height);

        let data = CAMERA_ENV.canvas.toDataURL('image/png');
        CAMERA_ENV.photoImg.setAttribute('src', data);
    }
}

